/* VzImagination (C) 2018-2019 Stephane Charette <stephanecharette@gmail.com>
 * $Id: TestMatManipErodeAndDilate.cpp 2741 2019-04-09 17:04:20Z stephane $
 */

#include "TestUtil.hpp"


TEST(Erode, Invalid)
{
	cv::Mat src;
	ASSERT_THROW(vz::erode(src), std::exception);
}


TEST(Erode, Iterations)
{
	for (const auto & [path, name] : test_images())
	{
		cv::Mat src = cv::imread(path);
		ASSERT_FALSE(src.empty());
		ASSERT_EQ(src.channels(), 3);

		cv::Mat balanced = vz::apply_simple_colour_balance(src);
		ASSERT_FALSE(balanced.empty());
		ASSERT_EQ(balanced.channels(), 3);

		cv::Mat grey = vz::to_greyscale(balanced);
		ASSERT_FALSE(grey.empty());
		ASSERT_EQ(grey.channels(), 1);

		for (int i : {1, 2, 3, 4, 5, 15})
		{
			std::cout << name << " image erosion iterations #" << i << std::endl;
			cv::Mat dst = vz::erode(grey, i);
			ASSERT_FALSE(dst.empty());

			cv::imwrite("erode_" + name + "_" + std::to_string(i) + ".jpg", dst, {cv::IMWRITE_JPEG_QUALITY, 75, cv::IMWRITE_JPEG_OPTIMIZE, 1});
		}
	}
}
